=begin
Copyright 2013, Chris Fullmer
All Rights Reserved

Disclaimer
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

License
This software is distributed under the Smustard End User License Agreement
http://www.smustard.com/eula

Information
Author - Chris Fullmer
Organization - www.ChrisFullmer.com and distributed on the SketchUp Extension Warehouse
Name - Component Stringer
SU Version - 2013, 8, 7

Description
This script will take a component and apply it to a series of edges - one component per edge.  
It stretches or scales the component to the length as the edges.

Usage
First select a series of connected edges (they can not form a closed loop) and a single component.  
Then activate the plugin at Plugins>Chris Fullmer Tools>Component Stringer.  
You can reverse the direction of the edges and choose to scale uniform, or stretch the component onto the edges.

History
1.0 2009-11-13
   * First release
1.2 2009-11-16
	* Added rotation and twist capabilities
	* developed and added my menu items for donations and youtube
	* Added a no-scaling option
1.3.0 2013-04-29
  * Added EW compatibility
  * Wrapped entire code into my own person namespace
  * Wrapped plugin into its own namespace inside my developer space
  * Fixed a bug that was preventing the tool from terminating correctly
  * Added the speed up argument to the start_operation command
1.3.1 2013-05-06
  * Fixed menu compatibility with older clf scripts  
=end


module CLF_Extensions_NS

  module CLF_Component_Stringer

    require 'sketchup.rb'
    require 'extensions.rb'
    
    NAME = "clf_component_stringer"
    UNAME = "CLF Component Stringer"
    MENU_NAME = "Component Stringer"
    version = "1.3.1"           #EDIT
    desc = "This plugin takes a selected component and 'strings' it along a series of lines or a curve, like stringing beads on a necklace."
    copy_year = "2013"
    author = "Chris Fullmer"
    
#------edit above--------------------------------------------------------------- 

    
    extension = SketchupExtension.new UNAME, NAME+"/"+NAME+"_menus.rb"

    #The name= method sets the name which appears for an extension inside the Extensions Manager dialog.
    extension.name = UNAME

    # The description= method sets the long description which appears beneath an extension inside the Extensions Manager dialog.
    extension.description = desc + "  Access it via Plugins > Chris Fullmer Tools > "+MENU_NAME

    # The version method sets the version which appears beneath an extension inside the Extensions Manager dialog.
    extension.version = version

    # Create an entry in the Extension list that loads a script called
    # stairTools.rb.
    extension.copyright = copy_year
     
    # The creator= method sets the creator string which appears beneath an extension inside the Extensions Manager dialog.
    extension.creator = author

    # The register_extension method is used to register an extension with SketchUp's extension manager (in SketchUp preferences).
    Sketchup.register_extension( extension, true )
    
  end
end


