# See the loader file for license and author info

require 'sketchup.rb'
module CLF_Extensions_NS
	module CLF_Component_Stringer
    def self.curve_ordering( edges )
      edge = []
      allverts = []
      temp_edge = [] 
      arc_first = true
      vert_array = []
      start_vert = []
      arc_endverts = []
      edges.each do |e|
        allverts << e.start << e.end
      end
      allverts.uniq!
      if arc_endverts.empty?
        allverts.each do |e| 
          if e.edges.length == 1
            arc_endverts << e
          end
        end
      else
        arc_endverts.reverse!
      end
      start_vert = [arc_endverts[0]]
      edges.length.times do
        vert_array << start_vert[0]
        if arc_first
          edge = start_vert[0].edges
        else
          two_edges = start_vert[0].edges
          edge = two_edges - temp_edge
        end
        temp_edge = edge
        two_verts = edge[0].vertices
        start_vert = two_verts - start_vert
        arc_first = false
      end
      vert_array << arc_endverts[1]
      curve_labeler( arc_endverts )
      vert_array
    end # curve_ordering

    def self.curve_labeler ( arc_endverts )
      if !$arc_labels.empty?
        Sketchup.active_model.entities.erase_entities $arc_labels
        $arc_labels = []
      end
      start_label = Sketchup.active_model.entities.add_text "Start", arc_endverts[0]
      end_label = Sketchup.active_model.entities.add_text "End", arc_endverts[1]
      $arc_labels << start_label << end_label
    end # curve_labeler




    def self.main
      model = Sketchup.active_model
      model.start_operation("Component Stringer", true)
      sel = model.selection
      ents = model.active_entities
      verts = []
      edges = []
      comp = []
      $arc_labels = []
      comp_height = []

      sel.each do |e|
      comp << e if e.is_a? Sketchup::ComponentInstance
      edges << e if e.is_a? Sketchup::Edge
      end
      
      if comp.length == 0 || edges.length == 0
        UI.messagebox("Please select an arc or series of connect lines, and a component first.")
        return
      end
      
      comp_height = comp[0].definition.bounds.depth

      vert_array = curve_ordering( edges )
      eval = UI.messagebox "Reverse Edges?", MB_YESNOCANCEL
      if eval == 6
        vert_array.reverse!
      elsif eval == 7
        puts "No reversing needed"	
      elsif eval == 2
        tool = model.select_tool nil
        ents.erase_entities( $arc_labels )
        return
      else
        tool = model.select_tool nil
        puts eval
        ents.erase_entities( $arc_labels )
        return
      end

      ents.erase_entities( $arc_labels )

      prompts = ["Scaling", "Component Rotation (Degrees)", "Total Rotation (Degrees)"]
      defaults = ["Uniform", 0.0, 0.0]
      values = ["Uniform|Stretch|None", "", ""]
      results = UI.inputbox( prompts, defaults, values, "Options" )
      comp_rot = results[1]
      comp_rot_count = 0.0
      overall_rot = results[2]
      overall_rot_count = 0.0
      overall_increment =  overall_rot / ((vert_array.length.to_f) - 2.0)
      vert_array.each_with_index do |e, index|
        if (index+1) < vert_array.length
          pt1 = vert_array[index].position
          pt2 = vert_array[index+1].position
          len = pt1.distance( pt2 )
          scale = len.to_f/comp_height.to_f
          t = Geom::Transformation.scaling(scale) if results[0] == "Uniform"
          t = Geom::Transformation.scaling(1, 1, scale) if results[0] == "Stretch"
          t = Geom::Transformation.new if results[0] == "None"
          instance = ents.add_instance comp[0].definition, t
          t = Geom::Transformation.rotation( instance.transformation.origin, [0,0,1], comp_rot_count.degrees )
          instance.transform! t
          t = Geom::Transformation.rotation( instance.transformation.origin, [0,0,1], overall_rot_count.degrees )
          instance.transform! t				
          t = Geom::Transformation.new( e.position, pt1.vector_to(pt2) )
          instance.transform! t
          comp_rot_count = comp_rot_count + comp_rot
          overall_rot_count = overall_rot_count + overall_increment
        end

      end
      model.commit_operation
    end
  end

end